@@ -10,10 +10,10 @@ use File::Basename 'dirname';
 use File::Spec::Functions qw' rel2abs catdir catfile ';
 use Cwd qw' getcwd realpath ';
 use Data::Dumper;
-# use Data::Printer;
+use Data::Printer;
 use Carp qw' croak confess ';
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 my $scripts_dir = realpath catdir(dirname(rel2abs(__FILE__)), '../../../share');
 $scripts_dir = catdir(dist_dir('JavaScript-V8-CommonJS'))
@@ -29,6 +29,7 @@ sub new {
     bless my $self = {
         paths   => $args->{paths}   || [getcwd()],
         modules => $args->{modules} || {},
+        v8_params => $args->{v8_params},
     }, $class;
 
     $self->{c} = $self->_build_ctx;
@@ -42,7 +43,7 @@ sub paths { shift->{paths} }
 
 sub _build_ctx {
     my $self = shift;
-    my $c = JavaScript::V8::Context->new;
+    my $c = JavaScript::V8::Context->new($self->{v8_params} ? %{$self->{v8_params}} : ());
 
     # global functions
     for my $name (qw/ resolveModule requireNative evalModuleFile /) {
@@ -243,6 +244,10 @@ Arrayref of paths to search for modules. Default: [getcwd()].
 
 Hashref of native modules. Default: {}.
 
+=item v8_params
+
+Hashref passed directly to L<JavaScript::V8::Context/new>. Default: undef.
+
 =back
 
 =head1 METHODS
